@@ -3,14 +3,15 @@
 //!
 //! [R3]: ::r3
 //! [Raspberry Pi Pico]: https://pico.raspberrypi.org
-#![feature(raw_ref_op)]
-#![feature(maybe_uninit_ref)]
-#![feature(asm)]
-#![feature(const_fn_trait_bound)]
+#![feature(exhaustive_patterns)]
+#![feature(const_trait_impl)]
 #![feature(const_mut_refs)]
-#![feature(const_fn_fn_ptr_basics)]
+#![feature(raw_ref_op)]
+#![cfg_attr(
+    feature = "doc",
+    doc(html_logo_url = "https://r3-os.github.io/r3/logo-small.svg")
+)]
 #![deny(unsafe_op_in_unsafe_fn)]
-#![deny(unsupported_naked_functions)]
 #![no_std]
 
 #[cfg(doc)]
